Documentation
¶
Overview ¶
Package vcs exposes interfaces and methods implemented by a VCS.
Index ¶
Constants ¶
const ( HTTPS = "https" HTTP = "http" SSHGit = "ssh+git" Git = "git" )
List of supported schemes.
Variables ¶
This section is empty.
Functions ¶
func Errorf ¶
Errorf returns a new error message by combining various errors with the name of the VCS as prefix.
func IsSecureScheme ¶
IsSecureScheme returns true if the given scheme is marked as secure.
Types ¶
type BasicAuthentifier ¶ added in v0.5.0
BasicAuthentifier must be implemented to allow request with basic host by hostname.
type ClientChooser ¶
ClientChooser must be implemented to return a HTTPClient Client for the given rawURL.
type HTTPClient ¶
type HTTPClient struct {
// contains filtered or unexported fields
}
HTTPClient allows to communicate over HTTPClient or HTTPS.
func NewHTTPClient ¶
func NewHTTPClient(timeout time.Duration, insecurePaths string) *HTTPClient
NewHTTPClient creates a new instance of Client.
func (*HTTPClient) AllowInsecure ¶
func (c *HTTPClient) AllowInsecure(target string) bool
AllowInsecure returns true if this rawURL allows insecure request.
func (*HTTPClient) ClientFor ¶
func (c *HTTPClient) ClientFor(path string) Client
ClientFor returns the HTTPClient client to use for this rawURL.
Click to show internal directories.
Click to hide internal directories.